"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Analyzer {
    constructor() {
        this.featureRegExp = new RegExp('^(feature)+[:]?', 'i');
        this.scenarioOutlineRegExp = new RegExp('^(scenario+[ ]+outline)+[:]?', 'i');
        this.scenarioRegExp = new RegExp('^(scenario)+[:]?', 'i');
        this.stateRegExp = new RegExp('^(given)+[:]?', 'i');
        this.actionRegExp = new RegExp('^(when)+[:]?', 'i');
        this.outcomeRegExp = new RegExp('^(then)+[:]?', 'i');
        this.glueRegExp = new RegExp('^(and|but)+[:]?', 'i');
        this.examplesTitleRegExp = new RegExp('^(examples|example)', 'i');
        this.examplesDataRegExp = new RegExp('^[|]', 'i');
    }
    getGherkins(listRows, index) {
        const features = [];
        const scenarios = [];
        const states = [];
        const actions = [];
        const outcomes = [];
        const files = [];
        let rowAnalyzed;
        let currentReadRow = '';
        for (const listRow of listRows) {
            if (rowAnalyzed = this.getValidFeature(listRow)) {
                features.push({ id: `fe-${index}-${features.length}`, text: rowAnalyzed });
                currentReadRow = 'feature';
            }
            else if (rowAnalyzed = this.getValidScenarioOutline(listRow)) {
                scenarios.push({ id: `sc-${index}-${scenarios.length}`, text: rowAnalyzed });
                currentReadRow = 'scenario';
            }
            else if (rowAnalyzed = this.getValidScenario(listRow)) {
                scenarios.push({ id: `sc-${index}-${scenarios.length}`, text: rowAnalyzed });
                currentReadRow = 'scenario';
            }
            else if (rowAnalyzed = this.getValidState(listRow, currentReadRow)) {
                states.push({ id: `st-${index}-${states.length}`, text: rowAnalyzed });
                currentReadRow = 'state';
            }
            else if (rowAnalyzed = this.getValidAction(listRow, currentReadRow)) {
                actions.push({ id: `ac-${index}-${actions.length}`, text: rowAnalyzed });
                currentReadRow = 'action';
            }
            else if (rowAnalyzed = this.getValidOutcome(listRow, currentReadRow)) {
                outcomes.push({ id: `ou-${index}-${outcomes.length}`, text: rowAnalyzed });
                currentReadRow = 'outcome';
            }
            else if (rowAnalyzed = this.getValidExampleTitle(listRow)) {
                currentReadRow = 'example';
            }
            else if (rowAnalyzed = this.getValidExampleData(listRow, currentReadRow)) {
                currentReadRow = 'example';
            }
            else {
                continue;
            }
            files.push({ id: `fi-${index}-${files.length}`, text: listRow });
        }
        return { files, features, scenarios, states, actions, outcomes };
    }
    getValidFeature(listRow) {
        const listRowToAnalyze = this.featureRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidScenarioOutline(listRow) {
        const listRowToAnalyze = this.scenarioOutlineRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidScenario(listRow) {
        const listRowToAnalyze = this.scenarioRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidState(listRow, previousRow) {
        const listRowToAnalyze = previousRow === 'state' ? this.glueRegExp.exec(listRow) : this.stateRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidAction(listRow, previousRow) {
        const listRowToAnalyze = previousRow === 'action' ? this.glueRegExp.exec(listRow) : this.actionRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidOutcome(listRow, previousRow) {
        const listRowToAnalyze = previousRow === 'outcome' ? this.glueRegExp.exec(listRow) : this.outcomeRegExp.exec(listRow);
        return listRowToAnalyze ? listRow.replace(listRowToAnalyze[0], '').trim() : null;
    }
    getValidExampleTitle(listRow) {
        const listRowToAnalyze = this.examplesTitleRegExp.exec(listRow);
        return listRowToAnalyze ? listRowToAnalyze[0].trim() : null;
    }
    getValidExampleData(listRow, previousRow) {
        if (previousRow === 'example') {
            const listRowToAnalyze = this.examplesDataRegExp.exec(listRow);
            return listRowToAnalyze ? listRow.trim() : null;
        }
        return null;
    }
}
exports.Analyzer = Analyzer;
